@@ -611,7 +611,7 @@ eel_stipple_bitmap_for_screen (GdkScreen *screen)
  * This method is not multiscreen safe. Do not use it.
  */
 GdkBitmap *
-eel_stipple_bitmap ()
+eel_stipple_bitmap (void)
 {
 	return eel_stipple_bitmap_for_screen (gdk_screen_get_default ());
 }
@@ -642,7 +642,7 @@ eel_gdk_window_focus (GdkWindow *window, guint32 timestamp)
 	gdk_error_trap_push ();
 	XSetInputFocus (GDK_DISPLAY (),
 			GDK_WINDOW_XWINDOW (window),
-			RevertToPointerRoot,
+			RevertToParent,
 			timestamp);
 	gdk_flush();
 	gdk_error_trap_pop ();
@@ -691,7 +691,7 @@ eel_gdk_window_set_wm_hints_input (GdkWindow *window, gboolean status)
 	}
 
 	wm_hints->flags |= InputHint;
-	wm_hints->input = status;
+	wm_hints->input = (status == FALSE) ? False : True;
 
 	XSetWMHints (dpy, id, wm_hints);
 	XFree (wm_hints);
