@@ -508,8 +508,23 @@ static int
 compare_applications (GMenuTreeEntry *a,
 		      GMenuTreeEntry *b)
 {
-	return g_utf8_collate (gmenu_tree_entry_get_name (a),
-			       gmenu_tree_entry_get_name (b));
+	const char *name_a = gmenu_tree_entry_get_name (a);
+	const char *name_b = gmenu_tree_entry_get_name (b);
+
+	if (name_a == NULL && name_b == NULL) {
+		return 0;
+	}
+
+	if (name_a == NULL) {
+		return -1;
+	}
+
+	if (name_b == NULL) {
+		return 1;
+	}
+
+	return g_utf8_collate (name_a,
+			       name_b);
 }
 
 static GSList *
@@ -552,7 +567,7 @@ get_all_applications (void)
 	GMenuTreeDirectory *root;
 	GSList             *retval;
 
-	tree = gmenu_tree_lookup ("applications.menu", GMENU_TREE_FLAGS_NONE);
+	tree = gmenu_tree_lookup ("applications.menu", GMENU_TREE_FLAGS_INCLUDE_NODISPLAY);
 
 	root = gmenu_tree_get_root_directory (tree);
 
@@ -594,7 +609,8 @@ eel_open_with_dialog_add_items_idle (EelOpenWithDialog *dialog)
 		GtkTreeIter     iter;
 		GtkTreePath    *path;
 
-		if (prev_name && strcmp (gmenu_tree_entry_get_name (entry), prev_name) == 0) {
+		const char *name = gmenu_tree_entry_get_name (entry);
+		if (!name || (prev_name && strcmp (name, prev_name) == 0)) {
 			gmenu_tree_item_unref (entry);
 			continue;
 		}
@@ -941,6 +957,7 @@ set_uri_and_mime_type (EelOpenWithDialog *dialog,
 {
 	char *label;
 	char *name;
+	char *emname;
 	GnomeVFSURI *vfs_uri;
 
 	dialog->details->uri = g_strdup (uri);
@@ -983,7 +1000,9 @@ set_uri_and_mime_type (EelOpenWithDialog *dialog,
 		dialog->details->mime_description = description;
 	}
 
-	label = g_strdup_printf (_("Open <i>%s</i> and other files of type \"%s\" with:"), name, dialog->details->mime_description);
+	emname = g_strdup_printf ("<i>%s</i>", name);
+	label = g_strdup_printf (_("Open %s and other files of type \"%s\" with:"), emname, dialog->details->mime_description);
+	g_free (emname);
 
 	gtk_label_set_markup (GTK_LABEL (dialog->details->label), label);
 
